/* Copyright 2005-2006 Michelle Osmond
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package message;

import java.util.*;

/**
 *  Storage and retrieval of portlet message mappings, and the messages. 
 *  Implement this interface if you want to create a custom Message Store.
 * 
 * @author Michelle Osmond
 * @version 1.1
 * @see MessageCentre
 */
public interface MessageStore {

    public void initialise(String sessionID);

    public void saveInputMapping(MessageBoxKey key, MessageBoxKey source);

    public void deleteInput(MessageBoxKey key);

	public void saveOutputMapping(MessageBoxKey key, MessageBoxKey target);

	public void clearAllOutputMappings(MessageBoxKey key);

    public void deleteOutput(MessageBoxKey key);

    public Set findOutputTargets(MessageBoxKey key);

    public MessageBoxKey getInputSource(MessageBoxKey key);

    public Object getMessage(MessageBoxKey key);

    public void sendMessage(Set targetKeys, Object message);

	public Set getInputKeys(String portletID);

	public Set getOutputKeys(String portletID);

    public Set getPublicBoxKeys();

	public Map getBoxes();

	public Set getAllInputKeys();

	public Set getAllOutputKeys();

    public boolean isValid();

}