/* Copyright 2005-2006 Michelle Osmond
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package message;

import java.util.*;

/**
 * Generates objects based on configuration settings in MessageConfig
 * 
 * @author Michelle Osmond
 * @version 1.1
 */
public class MessagingFactory {

	public static HashMap classes = new HashMap();

	/**
     * Get an object to retrieve the user-session-id.
     */
	public static SessionIDRetriever getSessionIDRetriever() throws ClassNotFoundException, InstantiationException, IllegalAccessException {
        return (SessionIDRetriever) getNewInstance(MessageConfig.SESSION_ID_RETRIEVER);
    }

	/**
     * Get a message centre for the given browser session ID.
     */
    public static MessageCentre getMessageCentre(String sessionID) throws ClassNotFoundException, InstantiationException, IllegalAccessException {
        MessageStore store = (MessageStore) getNewInstance(MessageConfig.MESSAGE_STORE);
        store.initialise(sessionID);
        MessageCentre mc = new MessageCentreImpl();
        mc.setStore(store);
        return mc;
    }

    protected static Object getNewInstance(String name) throws ClassNotFoundException, InstantiationException, IllegalAccessException { 
        Class retrieverClass = null;

        if (MessagingFactory.classes.containsKey(name)) {
            retrieverClass = (Class) MessagingFactory.classes.get(name);
        } else {
            // get class name from config
            retrieverClass = Class.forName(MessageConfig.getConfigProperty(name));
            MessagingFactory.classes.put(name, retrieverClass);
        }

        // instantiate class
        if (MessageConfig.debug()){
            System.out.println("MessagingFactory returning instance for "+name+" of class "+retrieverClass.getName());
        }
        return retrieverClass.newInstance();        
	}

}