package message.portlets;

import message.*;

import java.util.*;
import java.net.URLEncoder;
import javax.portlet.*;
import java.io.IOException;
import java.io.PrintWriter;

/** 
 * A portlet that receives messages (locally named "author" and "book"),
 * and uses them to generate an Amazon search.
 *
 * @author Michelle Osmond
 * @version 1.0
 * @see ListingPortlet
 * @see AmazonSearchBookPortlet
 */
public class AmazonSearchBookPortlet extends GenericPortlet
{

    public void doView(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {

		PortletSession portletSession = request.getPortletSession(true);
		String id = getInstanceID(request);
        String msg_session_id = MessageHelper.getSessionID(request);

		// load this portlet's inputs and outputs from preferences
		MessageHelper.loadPrefs(request, id, msg_session_id);

        response.setContentType( "text/html" );
        PrintWriter writer = response.getWriter();

		writer.write("<p><i>portlet instance id: "+id+"</i></p>");

		// Generate the search URL from the Author/Book messages, if present
		String search = "http://www.amazon.co.uk/exec/obidos/search-handle-url/index=books-uk&field-keywords=";

		MessageHelper helper = new MessageHelper(portletSession, id, msg_session_id);
		String broadcastAuthor = helper.getAsString("author");
		if (broadcastAuthor!=null && broadcastAuthor.length()>0){
			search += URLEncoder.encode(broadcastAuthor);
		}
		String broadcastBook = helper.getAsString("book");
		if (broadcastBook!=null && broadcastBook.length()>0){
			search += URLEncoder.encode(" "+broadcastBook);
		}

		writer.write("<iframe src=\""+search+"\" width='900' height='400'>No iframes... <a href=\""+search+"\" target=\"_blank\">Search Amazon</a></iframe>");

    }

    public void doEdit(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {
        doView(request, response);
    }

    public void doHelp(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {
    }

    public void processAction (ActionRequest request, ActionResponse actionResponse) 
		throws PortletException, java.io.IOException  {

    }

	public String getInstanceID(PortletRequest request){
		return "AmazonSearchBook"+MessageHelper.getPortletID(request);
	}
}
