package message.portlets;

import message.*;

import java.util.*;
import javax.portlet.*;
import java.io.IOException;
import java.io.PrintWriter;

/** 
 * A portlet that sends and receives messages.
 *
 * @author Michelle Osmond
 * @version 1.0
 * @see ListingPortlet
 * @see AmazonSearchBookPortlet
 */
public class AuthorDetailsPortlet extends GenericPortlet
{


    public void doView(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {

		PortletSession portletSession = request.getPortletSession(true);
		String id = getInstanceID(request);
        String msg_session_id = MessageHelper.getSessionID(request);

		// load this portlet's inputs and outputs from preferences
		MessageHelper.loadPrefs(request, id, msg_session_id);

        response.setContentType( "text/html" );
        PrintWriter writer = response.getWriter();

		writer.write("<p><i>portlet instance id: "+id+"</i></p>");

		MessageHelper helper = new MessageHelper(portletSession, id, msg_session_id);
		String broadcastAuthor = helper.getAsString("author");
		// print out the author details
		if (broadcastAuthor==null || broadcastAuthor.length()<=0){
			writer.write("No author selected.");
			return;
		}

		writer.write("<p>Selected author: <b>"+broadcastAuthor+"</b></p>");

		String website = Library.getWebsite(broadcastAuthor);
		writer.write("<p><a href=\""+website+"\">"+website+"</a></p>");

		// draw the book list
        writer.write("<p><b>Books:</b></p>");

		writer.write("<table border='0'>");
		writer.write("<tr><th>Title</th></tr>");
		SortedSet books = Library.getBooks(broadcastAuthor);

		PortletURL bookUrl = response.createActionURL();
		bookUrl.setParameter("myAuthor",broadcastAuthor);

		for (Iterator it=books.iterator(); it.hasNext();){
			String book = it.next().toString();
			bookUrl.setParameter("myBook",book);
			writer.write("<tr>");
			writer.write("<td><a href='"+bookUrl.toString()+"'>"+book+"</a></td>");
			writer.write("</tr>");
		}

		writer.write("</table>");
    }

    public void doEdit(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {
        doView(request, response);
    }

    public void doHelp(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {
    }


    public void processAction (ActionRequest request, ActionResponse actionResponse) 
		throws PortletException, java.io.IOException  {
              
		PortletSession portletSession = request.getPortletSession(true);

		String id = getInstanceID(request);
        String msg_session_id = MessageHelper.getSessionID(request);
		MessageHelper helper = new MessageHelper(portletSession, id, msg_session_id);

        String myAuthor = request.getParameter("myAuthor");
		if (myAuthor!=null && myAuthor.length()>0){
			helper.send("author", myAuthor);		
		}

        String myBook = request.getParameter("myBook");
		if (myBook!=null && myBook.length()>0){
			helper.send("book", myBook);
		}

    }

	public String getInstanceID(PortletRequest request){
		return "AuthorDetails"+MessageHelper.getPortletID(request);
	}
}
