/* Copyright 2005-2006 Michelle Osmond
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package message.portlets;

import java.io.IOException;
import java.io.PrintWriter;

import javax.portlet.*;

/** 
 *  This portlet sets a cookie with a session id that should be visible
 *  to all portlet applications on that portal.
 *  
 *  This portlet should be on the first page after log on, so it can set
 *  the cookie before any other messaging portlets render. It has to do this
 *  in the Render phase... so (annoyingly) you shouldn't put any messaging 
 *  portlets on that page either.
 * 
 *  Used in combination with the CookieSessionIDRetriever, and an external
 *  MessageStore, this could be used quickly on any portal for testing out
 *  messaging between different portlet webapps. 
 * 
 *  However, for production use it would be better to use a more robust 
 *  (portal-specific) solution to set the session id.
 * 
 */
public class CookieSetterPortlet extends GenericPortlet{

    protected static String SET_COOKIE = "set_cookie";
    protected static String COOKIE_NAME = "cookie_msg_session_id";

	protected void doView(RenderRequest request, RenderResponse response) throws PortletException, IOException {
			
        // See if we have already set the cookie this session - check
        // in the local portlet's session (no good just checking the 
        // cookie, it might be an old one)
        if (request.getPortletSession(true).getAttribute(SET_COOKIE)!=null){
            // have set the cookie already.
            return;
        }

        // Need to set the cookie.
        
        // Just use the local portlet session ID as the message session id
		String cookie_value = request.getPortletSession(true).getId();
        // expiry time
        String cookie_hours = "6";

        StringBuffer buf = new StringBuffer();
        buf.append("\n <script>");
        buf.append("\n var today = new Date();");
        buf.append("\n var expires_date = new Date ( today.getTime() + (" + cookie_hours + "*1000*60*60) );");
        buf.append("\n document.cookie = \"" + COOKIE_NAME + "=" + cookie_value + ";expires=\"+expires_date.toGMTString();");    
        buf.append("\n </script>");
		
		response.setContentType("text/html");
		PrintWriter out = response.getWriter();
        out.println(buf.toString());

        // record in the portlet session that we have set the cookie
        request.getPortletSession(true).setAttribute(SET_COOKIE, cookie_value);
	}

}
