package message.portlets;

import message.*;

import java.util.*;
import java.net.URLEncoder;
import javax.portlet.*;
import java.io.IOException;
import java.io.PrintWriter;

/** 
 * This is an example of a simple, complete portlet with message mappings 
 * configurable by the portal user. There is one input mapping, with 
 * internal name "search".
 * It uses edit_mappings.jsp and the functions in MessageUtils to do the
 * dynamic mappings.
 *
 * @author Michelle Osmond
 * @version 1.0
 * @see WiredListingPortlet
 * @see message.MessageUtils
 */
public class EbaySearchBookPortlet extends JSPPortlet
{

    public void doView(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {

		PortletSession portletSession = request.getPortletSession(true);
		String id = getInstanceID(request);
        String msg_session_id = MessageHelper.getSessionID(request);

		// load this portlet's message mappings from preferences
		MessageHelper.loadPrefs(request, id, msg_session_id);

        response.setContentType( "text/html" );
        PrintWriter writer = response.getWriter();

		writer.write("<p><i>portlet instance id: "+id+"</i></p>");

		// Generate the search URL using the "search" message
		String search = "http://search.ebay.co.uk/search/search.dll?GetResult&category0=267&query=";
		MessageHelper helper = new MessageHelper(portletSession, id, msg_session_id);
		String broadcastSearch = helper.getAsString("search");
		if (broadcastSearch!=null && broadcastSearch.length()>0){
			search += URLEncoder.encode(broadcastSearch);
		}

		writer.write("<iframe src=\""+search+"\" width='900' height='400'>No iframes... <a href=\""+search+"\" target=\"_blank\">Search Ebay</a></iframe>");

    }

    public void doEdit(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {

		PortletSession portletSession = request.getPortletSession(true);
		String id = getInstanceID(request);
        String msg_session_id = MessageHelper.getSessionID(request);

		// load this portlet's inputs and outputs from preferences
		MessageHelper.loadPrefs(request, id, msg_session_id);

		MessageUtils.prepareMappingForm(request, id, msg_session_id);
		include(request, response, "/WEB-INF/jsp/edit_mappings.jsp");

    }

    public void doHelp(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {

    }

    public void processAction (ActionRequest request, ActionResponse actionResponse) 
		throws PortletException, java.io.IOException  {

		PortletSession portletSession = request.getPortletSession(true);

		if (request.getPortletMode().equals(PortletMode.EDIT)) {

			String id = getInstanceID(request);
            String msg_session_id = MessageHelper.getSessionID(request);
			MessageUtils.processMappingForm(request, actionResponse, id, msg_session_id);

		}
    }

	public String getInstanceID(PortletRequest request){
		return "EbaySearchBook"+MessageHelper.getPortletID(request);
	}

}
