package message.portlets;

import message.*;

import java.util.*;
import javax.portlet.*;
import java.io.IOException;
import java.io.PrintWriter;

/** 
 * A portlet that sends and receives messages.
 *
 * @author Michelle Osmond
 * @version 1.0
 * @see WiredListingPortlet
 * @see AuthorDetailsPortlet
 * @see AmazonSearchBookPortlet
 */
public class ListingPortlet extends JSPPortlet
{

    public void doView(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {

		PortletSession portletSession = request.getPortletSession(true);
		String id = getInstanceID(request);
        String msg_session_id = MessageHelper.getSessionID(request);

		// load this portlet's inputs and outputs from preferences
		MessageHelper.loadPrefs(request, id, msg_session_id);

        response.setContentType( "text/html" );
        PrintWriter writer = response.getWriter();

		writer.write("<p><i>portlet instance id: "+id+"</i></p>");

		// See if there has been any messages broadcast that we need to pick up
		MessageHelper helper = new MessageHelper(portletSession, id, msg_session_id);
		String broadcastAuthor = helper.getAsString("author");
		String broadcastBook = helper.getAsString("book");
		// all we do with the messages is print them out 
		if (broadcastAuthor!=null && broadcastAuthor.length()>0){
			writer.write("<p>Selected author: <b>"+broadcastAuthor+"</b></p>");
		} 
		if (broadcastBook!=null && broadcastBook.length()>0){
			writer.write("<p>Selected book: <b>"+broadcastBook+"</b></p>");
		}

		// draw the listing table
        writer.write("<p><b>All books:</b></p>");

		writer.write("<table border='1'>");
		writer.write("<tr><th>Author</th><th>Title</th></tr>");
		SortedMap listing = Library.getListing();
		for (Iterator it=listing.keySet().iterator(); it.hasNext();){
			String author = it.next().toString();

			PortletURL authorUrl = response.createActionURL();
			authorUrl.setParameter("myAuthor",author);
			authorUrl.setParameter("myBook","");
			PortletURL bookUrl = response.createActionURL();
			bookUrl.setParameter("myAuthor",author);

			Set books = (Set) listing.get(author);

			for (Iterator it2=books.iterator(); it2.hasNext();){
				String book = it2.next().toString();
				bookUrl.setParameter("myBook",book);
				writer.write("<tr>");
				writer.write("<td><a href='"+authorUrl.toString()+"'>"+author+"</a></td>");
				writer.write("<td><a href='"+bookUrl.toString()+"'>"+book+"</a></td>");
				writer.write("</tr>");
			}
		}

		writer.write("</table>");
    }

    public void doEdit(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {
        doView(request, response);
    }

    public void doHelp(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {

    }


    public void processAction (ActionRequest request, ActionResponse actionResponse) 
		throws PortletException, java.io.IOException  {
              
		PortletSession portletSession = request.getPortletSession(true);

		String id = getInstanceID(request);
        String msg_session_id = MessageHelper.getSessionID(request);
		MessageHelper helper = new MessageHelper(portletSession, id, msg_session_id);

        String myAuthor = request.getParameter("myAuthor");
		if (myAuthor!=null){
			helper.send("author", myAuthor);		
		}

        String myBook = request.getParameter("myBook");
		if (myBook!=null){
			helper.send("book", myBook);
		}
    }

	public String getInstanceID(PortletRequest request){
		return "Listing"+MessageHelper.getPortletID(request);
	}
}
