package message.portlets;

import message.*;

import java.util.*;
import javax.portlet.*;
import java.io.IOException;
import java.io.PrintWriter;

/** 
 * This is an example of a portlet with message mappings configurable by
 * the portal user. It extends ListingPortlet, adding this new functionality.
 * It uses edit_mappings.jsp and the functions in MessageUtils to do the
 * dynamic mappings.
 *
 * @author Michelle Osmond
 * @version 1.0
 * @see EbaySearchBookPortlet
 * @see message.MessageUtils
 */
public class WiredListingPortlet extends ListingPortlet
{

    public void doView(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {

		// do the normal view
		super.doView(request, response);
	}

    public void doEdit(RenderRequest request, RenderResponse response) 
		throws PortletException, IOException {
        
		PortletSession portletSession = request.getPortletSession(true);
		String id = getInstanceID(request);
        String msg_session_id = MessageHelper.getSessionID(request);

		// load this portlet's inputs and outputs from preferences
		MessageHelper.loadPrefs(request, id, msg_session_id);

		MessageUtils.prepareMappingForm(request, id, msg_session_id);
		include(request, response, "/WEB-INF/jsp/edit_mappings.jsp");
    }

    public void processAction (ActionRequest request, ActionResponse actionResponse) 
		throws PortletException, java.io.IOException  {
              
		PortletSession portletSession = request.getPortletSession(true);
	
		if (request.getPortletMode().equals(PortletMode.EDIT)) {

			String id = getInstanceID(request);
            String msg_session_id = MessageHelper.getSessionID(request);
			MessageUtils.processMappingForm(request, actionResponse, id, msg_session_id);

		} else if (request.getPortletMode().equals(PortletMode.VIEW)) {
			super.processAction(request, actionResponse);
		}        
    }

	public String getInstanceID(PortletRequest request){
		return "WiredListing"+MessageHelper.getPortletID(request);
	}
}
